@@ -11,6 +11,8 @@ module_path = pathlib.Path(__file__).parent.absolute()
 macro_path = module_path
 stylesheet_path = os.path.join(module_path, 'stylesheets')
 
+# ROOT.gInterpreter.AddIncludePath(os.path.join(macro_path, "macros"))
+
 MAX_WORKERS = 8
 
 from quickstats.utils.io import VerbosePrint
@@ -19,3 +21,4 @@ _PRINT_ = VerbosePrint("INFO")
 
 from quickstats.main import *
 
+from quickstats.components.asimov_generator import AsimovType
