@@ -35,9 +35,10 @@ import click
 @click.option('--int_bin_precision', type=float, default=-1., help='Integrate the PDF over the bins '
                                                                    'instead of using the probability '
                                                                    'density at the bin centre')
-@click.option('--parallel', type=int, default=0, help='Parallelize job across different nuisance'+\
-                                                      'parameters using N workers.'+\
-                                                      'Use -1 for N_CPU workers.')
+@click.option('--parallel', type=int, default=-1, show_default=True,
+              help='\b Parallelize job across the N workers.'
+                   '\b Case  0: Jobs are run sequentially (for debugging).\n'
+                   '\b Case -1: Jobs are run across N_CPU workers.\n')
 @click.option('--cache/--no-cache', default=True, help='Cache existing result')
 @click.option('--exclude', default="", help='Exclude NPs (wildcard is accepted)')
 def run_pulls(**kwargs):
@@ -171,11 +172,13 @@ def plot_pulls(**kwargs):
               help='Optimize constant terms')
 @click.option('--offset/--no-offset', default=True, show_default=True,
               help='Offset likelihood')
-@click.option('-v', '--verbosity', default="WARNING", show_default=True,
-              help='verbosity level ("DEBUG", "INFO", "WARNING", "ERROR")')
+@click.option('-v', '--verbosity', default='INFO', show_default=True,
+              type=click.Choice(["DEBUG", "INFO", "WARNING", "ERROR"], case_sensitive=False),
+              help='Verbosity level.')
 @click.option('--parallel', type=int, default=-1, show_default=True,
-              help='Parallelize job across different scan values.'+\
-                   'Use -1 for N_CPU workers.')
+              help='\b Parallelize job across the N workers.'
+                   '\b Case  0: Jobs are run sequentially (for debugging).\n'
+                   '\b Case -1: Jobs are run across N_CPU workers.\n')
 def likelihood_scan(**kwargs):
     """
     Tool for likelihood scan
@@ -194,7 +197,7 @@ def likelihood_scan(**kwargs):
               help='Name of output')
 @click.option('--blind/--unblind', 'do_blind', default=True, show_default=True,
               help='Blind/unblind analysis')
-@click.option('--CL', 'CL', default=0.95, show_default=True,
+@click.option('--CL', 'CL', type=float, default=0.95, show_default=True,
               help='CL value to use')
 @click.option('--precision', default=0.005, show_default=True,
               help='precision in mu that defines iterative cutoff')
@@ -253,8 +256,9 @@ def likelihood_scan(**kwargs):
                    'density at the bin centre')
 @click.option('--constrain/--no-constrain', 'constrain_nuis', default=True, show_default=True,
               help='Use constrained NLL')
-@click.option('-v', '--verbosity',  default="INFO", show_default=True,
-              help='verbosity level ("DEBUG", "INFO", "WARNING", "ERROR")')
+@click.option('-v', '--verbosity', default='INFO', show_default=True,
+              type=click.Choice(["DEBUG", "INFO", "WARNING", "ERROR"], case_sensitive=False),
+              help='Verbosity level.')
 def cls_limit(**kwargs):
     """
     Tool for evaluating Asymptotic CLs limit
@@ -373,7 +377,7 @@ def generate_asimov(**kwargs):
 @click.option('-s', '--snapshot', 'snapshot_name', default=None, show_default=True,
               help='Name of initial snapshot')
 @click.option('-t', '--asimov_types', default="0,1,2", show_default=True,
-              help='\b\nTypes of asimov dataset to generate separated by commas.\n'
+              help='\b Types of asimov dataset to generate separated by commas.\n'
                    '\b 0: fit with POI fixed to 0\n'
                    '\b 1: fit with POI fixed to 1\n'
                    '\b 2: fit with POI free and set POI to 1 after fit\n'
@@ -426,9 +430,13 @@ def generate_standard_asimov(**kwargs):
 @click.option('--cache/--no-cache', default=True,  show_default=True,
               help='Cache existing batch results.')
 @click.option('--fit_options', default=None, help='A json file specifying the fit options.')
-@click.option('--verbosity', default="ERROR", help='Quickstats internal verbosity level.')
-@click.option('--parallel', type=int, default=-1, help='Parallelize job across different scan values.'+\
-                                                       'Use -1 for N_CPU workers.')
+@click.option('-v', '--verbosity', default='INFO', show_default=True,
+              type=click.Choice(["DEBUG", "INFO", "WARNING", "ERROR"], case_sensitive=False),
+              help='Verbosity level.')
+@click.option('--parallel', type=int, default=-1, show_default=True,
+              help='\b Parallelize job across the N workers.'
+                   '\b Case  0: Jobs are run sequentially (for debugging).\n'
+                   '\b Case -1: Jobs are run across N_CPU workers.\n')
 def toy_significance(**kwargs):
     """
     Generate toys and evaluate significance
@@ -487,12 +495,14 @@ def toy_significance(**kwargs):
               help='Use NLL offset.')
 @click.option('--print_level', type=int, default=-1, show_default=True,
               help='Minimizer print level')
-@click.option('--verbosity', default="INFO", show_default=True,
-              help='Quickstats internal verbosity level.')
+@click.option('-v', '--verbosity', default='INFO', show_default=True,
+              type=click.Choice(["DEBUG", "INFO", "WARNING", "ERROR"], case_sensitive=False),
+              help='Verbosity level.')
 @click.option('--snapshot', 'snapshot_name', default=None, help='Name of initial snapshot')
 @click.option('--parallel', type=int, default=-1, show_default=True,
-              help='Parallelize job across different scan values.'+\
-                   'Use -1 for N_CPU workers.')
+              help='\b Parallelize job across the N workers.'
+                   '\b Case  0: Jobs are run sequentially (for debugging).\n'
+                   '\b Case -1: Jobs are run across N_CPU workers.\n')
 def toy_limit(**kwargs):
     """
     Generate toys and evaluate limits
