@@ -138,7 +138,7 @@ class AsymptoticCLs(AnalysisObject):
             
     def load_snapshot(self, name:str):
         snapshot = self.ws.getSnapshot(name)
-        if not snapshot:
+        if snapshot == None:
             raise RuntimeError('snapshot "{}" does not exist'.format(name))
         self.stdout.debug('INFO: Loaded snapshot "{}"'.format(name))
         self.ws.loadSnapshot(name)
