@@ -94,6 +94,7 @@ class ExtendedMinimizer(AbstractObject):
     def data(self, val):
         assert isinstance(val, ROOT.RooAbsData)
         self._data = val
+        self.nll = None
     
     @property
     def pdf(self):
@@ -127,6 +128,9 @@ class ExtendedMinimizer(AbstractObject):
                                                   self.config['print_level'])
         return None
     
+    def set_data(self, data:"ROOT.RooAbsData"):
+        self.data = data
+    
     def create_nll(self, nll_command_list:List["ROOT.RooCmdArg"]=None):
         if (not self.nll) or (not self.config['reuse_nll']):
             if nll_command_list is None:
@@ -179,6 +183,7 @@ class ExtendedMinimizer(AbstractObject):
             commands.append(ROOT.RooFit.IntegrateBins(int_bin_precision))
         if constrain is not None:
             commands.append(ROOT.RooFit.Constrain(constrain))
+            self.stdout.warning("Use of `Constrain` option from createNLL is not recommended")
         if global_observables is not None:
             commands.append(ROOT.RooFit.GlobalObservables(global_observables))            
         self.nll_command_list = self.parse_nll_commands(commands)
