@@ -135,7 +135,7 @@ class NuisanceParameterPull(object):
         minimizer = ExtendedMinimizer("minimizer", model.pdf, model.data)
         print("INFO: Starting minimization")
         nll_commands = [ROOT.RooFit.NumCPU(num_cpu, 3),
-                        ROOT.RooFit.Constrain(model.nuisance_parameters),
+                        #ROOT.RooFit.Constrain(model.nuisance_parameters),
                         ROOT.RooFit.GlobalObservables(model.global_observables), 
                         ROOT.RooFit.Offset(offset)]
         if hasattr(ROOT.RooFit, "BatchMode"):
