@@ -1,5 +1,6 @@
 from typing import Optional, List, Dict
 import fnmatch
+import os
 import re
 import ROOT
 
@@ -17,6 +18,7 @@ class RooProcAction(object):
         formatted_parameters = {}
         for k,v in self._params.items():
             if v is None:
+                formatted_parameters[k] = None
                 continue
             k_literals = re.findall(r"\${(\w+)}", k)
             if isinstance(v, list):
@@ -28,15 +30,20 @@ class RooProcAction(object):
                     raise RuntimeError(f"the substitute literal `{literal}` is undefined")
             for literal in k_literals:
                 substitute = global_vars[literal]
-                k = k.replace("${" + literal + "}", substitute)
+                k = k.replace("${" + literal + "}", str(substitute))
             for literal in v_literals:
                 substitute = global_vars[literal]
-                v = v.replace("${" + literal + "}", substitute)
+                v = v.replace("${" + literal + "}", str(substitute))
             if '__SEPARATOR__' in v:
                 v = v.split("__SEPARATOR__")
             formatted_parameters[k] = v
         return formatted_parameters
     
+    def makedirs(self, fname):
+        dirname = os.path.dirname(fname)
+        if not os.path.exists(dirname):
+            os.makedirs(dirname)
+
     def _execute(self, rdf, **kwargs):
         return rdf
     
@@ -147,10 +154,13 @@ class RooProcFilter(RooProcAction):
     
 class RooProcSave(RooProcAction):
     
-    def __init__(self, treename:str, filename:str, columns:Optional[List[str]]=None):
+    def __init__(self, treename:str, filename:str, 
+                 columns:Optional[List[str]]=None,
+                 frame:Optional[str]=None):
         super().__init__(treename=treename,
                          filename=filename,
-                         columns=columns)
+                         columns=columns,
+                         frame=frame)
         
     @classmethod
     def parse(cls, text):
@@ -169,6 +179,7 @@ class RooProcSave(RooProcAction):
             for column in columns:
                 save_columns += [c for c in all_columns if fnmatch.fnmatch(c, column)]
             save_columns = list(set(save_columns))
+            self.makedirs(filename)
             rdf_next = rdf.Snapshot(treename, filename, save_columns)
         return rdf_next
     
@@ -200,6 +211,7 @@ class RooProcReport(RooProcAction):
         if int(display):
             print(df)
         if filename is not None:
+            self.makedirs(filename)
             df.to_csv(filename)
         return rdf
     
@@ -257,6 +269,23 @@ class RooProcDeclare(RooProcAction):
         expression = kwargs['expression']
         self.declare_expression(expression, name)
         return rdf
+    
+class RooProcSaveFrame(RooProcAction):
+    def __init__(self, name:str):
+        super().__init__(name=name)
+
+    @classmethod
+    def parse(cls, text):
+        return cls(name=text)
+    
+class RooProcLoadFrame(RooProcAction):
+    def __init__(self, name:str):
+        super().__init__(name=name)
+
+    @classmethod
+    def parse(cls, text):
+        return cls(name=text)    
+    
 
 ACTION_MAP = {
     'TREENAME': RooProcTreeName,
@@ -267,5 +296,7 @@ ACTION_MAP = {
     'SAVE': RooProcSave,
     'REPORT': RooProcReport,
     'GETSUM': RooProcSum,
-    'EXPORT': RooProcExport
+    'EXPORT': RooProcExport,
+    'SAVE_FRAME': RooProcSaveFrame,
+    'LOAD_FRAME': RooProcLoadFrame
 }
\ No newline at end of file
