@@ -130,8 +130,7 @@ TEMPLATE_STYLES = {
 
 ANALYSIS_OPTIONS = {
     'default': {
-        'x': 0.05,
-        'y': 0.95,
+        'loc': (0.05, 0.95),
         'fontsize': 20
     },
     'Run2': {
@@ -325,7 +324,7 @@ def draw_text(axis, x, y, s, transform_x:str='axis',
     return xmin, xmax, ymin, ymax
 
 
-def draw_ATLAS_label(axis, x=0.05, y=0.95, fontsize=25, extra='Internal', 
+def draw_ATLAS_label(axis, loc=(0.05, 0.95), fontsize=25, extra='Internal', 
                      transform_x='axis', transform_y='axis', 
                      vertical_align='top', horizontal_align='left'):
     current_axis = plt.gca()
@@ -336,6 +335,7 @@ def draw_ATLAS_label(axis, x=0.05, y=0.95, fontsize=25, extra='Internal',
         raise ValueError('only "left" or "right" horizontal alignment is allowed') 
     transform = transforms.blended_transform_factory(parse_transform(transform_x), 
                                                      parse_transform(transform_y))
+    x, y = loc
     text_atlas = axis.text(x, y, 'ATLAS', fontsize=fontsize, transform=transform,
                            horizontalalignment=horizontal_align,
                            verticalalignment=vertical_align,
@@ -349,7 +349,7 @@ def draw_ATLAS_label(axis, x=0.05, y=0.95, fontsize=25, extra='Internal',
     _, xmax, _, ymax = get_box_dimension(text_atlas)
     return xmin, xmax, ymin, ymax
 
-def draw_atlas_label(axis, x=0.05, y=0.95, fontsize=25, status:str='int',
+def draw_atlas_label(axis, loc=(0.05, 0.95), fontsize=25, status:str='int',
                      energy:Optional[str]=None, lumi:Optional[str]=None,
                      extra_text:Optional[str]=None, dy:float=0.05,
                      transform_x:str='axis', transform_y:str='axis',
@@ -368,7 +368,7 @@ def draw_atlas_label(axis, x=0.05, y=0.95, fontsize=25, status:str='int',
     else:
         status_str = status
         
-    xmin, xmax, ymin, ymax = draw_ATLAS_label(axis, x, y, fontsize, extra=" "+status_str,
+    xmin, xmax, ymin, ymax = draw_ATLAS_label(axis, loc, fontsize, extra=" "+status_str,
                                               transform_x=transform_x,
                                               transform_y=transform_y)
 
