@@ -1,8 +1,10 @@
 from typing import Optional, Union, Dict
 import os
 import sys
+import copy
 import time
 import json
+import inspect
 import datetime
 import functools
 import collections.abc
@@ -118,4 +120,28 @@ def update_nested_dict(d:Dict, u:Dict):
             d[k] = update_nested_dict(d.get(k, {}), v)
         else:
             d[k] = v
-    return d
\ No newline at end of file
+    return d
+
+def combine_dict(d:Dict, u:Optional[Dict]=None):
+    d_copy = copy.deepcopy(d)
+    if u is None:
+        return d_copy
+    else:
+        u_copy = copy.deepcopy(u)
+        return update_nested_dict(d_copy, u_copy)
+
+def get_class_that_defined_method(meth):
+    if isinstance(meth, functools.partial):
+        return get_class_that_defined_method(meth.func)
+    if inspect.ismethod(meth) or (inspect.isbuiltin(meth) and getattr(meth, '__self__', None) is not None and getattr(meth.__self__, '__class__', None)):
+        for cls in inspect.getmro(meth.__self__.__class__):
+            if meth.__name__ in cls.__dict__:
+                return cls
+        meth = getattr(meth, '__func__', meth)  # fallback to __qualname__ parsing
+    if inspect.isfunction(meth):
+        cls = getattr(inspect.getmodule(meth),
+                      meth.__qualname__.split('.<locals>', 1)[0].rsplit('.', 1)[0],
+                      None)
+        if isinstance(cls, type):
+            return cls
+    return getattr(meth, '__objclass__', None)
\ No newline at end of file
