@@ -1,3 +1,7 @@
+from typing import Union, Optional, Dict, List
+
+import pandas as pd
+
 import ROOT
 
 def copy_attributes(source:"ROOT.RooAbsArg", target:"ROOT.RooAbsArg"):
@@ -8,6 +12,24 @@ def copy_attributes(source:"ROOT.RooAbsArg", target:"ROOT.RooAbsArg"):
     for attrib in source.stringAttributes():
         target.setStringAttribute(attrib.first, attrib.second)
         
+def get_variable_attributes(variable:ROOT.RooRealVar):
+    attributes = {
+        'name' : variable.GetName(),
+        'value': variable.getVal(),
+        'error': variable.getError(),
+        'min'  : variable.getMin(),
+        'max'  : variable.getMax(),
+        'is_constant': variable.isConstant()
+    }
+    return attributes
+
+def variable_collection_to_dataframe(var_collection:Union[list, ROOT.RooArgSet, ROOT.RooArgSet]):
+    data = []
+    for variable in var_collection:
+        attributes = get_variable_attributes(variable)
+        data.append(attributes)
+    df = pd.DataFrame(data)
+    return df
         
 def construct_categorized_pdf_dataset(pdf:"ROOT.RooAbsPdf", dataset:"ROOT.RooDataSet", 
                                workspace:"ROOT.RooWorkspace", label:str,
